<?php
/**
 * WooCommerce class
 *
 * @package WavePlayer/WavePlayer
 */

namespace PerfectPeach\WavePlayer;

use Barn2\Plugin\Document_Library_Pro\Posts_Table_Pro\Util\Util;

defined( 'ABSPATH' ) || exit;

/**
 * WavePlayer class
 *
 * The main class of the plugin
 *
 * @since 3.7.1
 * @package WavePlayer/WavePlayer
 */
class Document_Library_Pro {
	/**
	 * Load the integration
	 *
	 * @since 3.7.1
	 * @return void
	 */
	public static function load() {
		add_filter( 'document_library_pro_filled_args', array( __CLASS__, 'set_post_type' ) );
		add_filter( 'document_library_pro_grid_image', array( __CLASS__, 'grid_image' ), 10, 2 );
		add_filter( 'waveplayer_additional_styles', array( __CLASS__, 'additional_styles' ) );
	}

	/**
	 * Set the post type to audio attachments
	 *
	 * @since 3.7.1
	 * @param array $args The args.
	 * @return array
	 */
	public static function set_post_type( $args ) {
		$args['post_type'] = 'attachment:audio';

		return $args;
	}

	/**
	 * Filter the grid image
	 *
	 * The image in the grid is replaced with the audio player using the Thumb'n'Wave skin.
	 *
	 * @since 3.7.1
	 * @param string $html The HTML.
	 * @param object $attachment The attachment.
	 * @return string
	 */
	public static function grid_image( $html, $attachment ) {
		if ( wp_attachment_is( 'audio', $attachment ) ) {
			$player = do_shortcode( "[waveplayer ids=\"{$attachment->ID}\" skin=\"thumb_n_wave\" ]" );

			$html = $player;
		}

		return $html;
	}

	public static function additional_styles( $css ) {
		$css .= '.dlp-grid-card-featured-img .waveplayer-container{flex:1}';

		return $css;
	}

	public static function get_audio_fields() {
		$internal_track_fields = Cache::get_transient( 'global', 'internal_track_properties' );

		foreach ( $internal_track_fields as $field ) {
			
		}
	}
}

Document_Library_Pro::load();
